Error

Struct Error 

pub struct Error { /* private fields */ }
A good general-purpose error type.

If debug_assertions and the alloc feature are enabled, then this error will have the same behavior as BoxedError. Otherwise, it will behave like Failure.